xquery version "3.1";

declare namespace repo="http://exist-db.org/xquery/repo";
declare namespace xconf="http://exist-db.org/collection-config/1.0";
declare namespace cpcf="http://sepia.io/content-parser/ns/configfile";

(: the target collection into which the app is deployed :)
declare variable $target external;

let $project-name := tokenize($target, "/")[last()]
let $log := util:log-system-out("installing " || $project-name)

let $fileSeparator := util:system-property("file.separator")
let $system-path := system:get-exist-home() || $fileSeparator
let $use-template :=
    if(doc-available($target || "/textgrid/data/collection-template.xconf"))
    then xmldb:rename($target || "/textgrid/data", "collection-template.xconf", "collection.xconf")
    else true()
let $move-indexes :=
    if(doc-available($target || "/search/edition/collection.xconf"))
    then xmldb:move($target || "/search/edition", "/db/system/config/db/data/sade/resources/tei", "collection.xconf")
    else true()
let $move-indexes :=
    if(doc-available($target || "/search/register/collection.xconf"))
    then xmldb:move($target || "/search/register", "/db/system/config/db/data/sade/resources/register", "collection.xconf")
    else true()
let $data-xconf := $target || "/textgrid/data/collection.xconf"
let $store-xconf := xmldb:store("/db/system/config" || $target || "/textgrid/data", "collection.xconf", doc( $data-xconf ))
let $reindex := xmldb:reindex($target || "/textgrid/data")

(: we have to test for writable path :)
let $path := $system-path
let $user := util:system-property("user.name")
let $message1 := $path || " is not available. Create it and make sure "
                || $user || " can write there."
let $message2 := "could not write to " || $path || "."
let $test :=
    if
        (file:is-directory($path))
    then
        try { file:serialize-binary( xs:base64Binary(util:base64-encode("beacon")) , $path || "beacon.txt") }
        catch * { util:log-system-out( "&#27;[48;2;"|| "255;0;0" ||"m&#27;[38;2;0;0;0m " ||
        $message2 || " &#27;[0m" ) }
    else
        util:log-system-out( "&#27;[48;2;"|| "255;0;0" ||"m&#27;[38;2;0;0;0m " ||
        $message1 || " &#27;[0m" )
let $message := util:log-system-out("create user 'kmg-publish'")
let $add_user := sm:create-account("kmg-publish", "", "dba", "")

(: setup content parser config :)
let $log := util:log-system-out("Updating content parser config")
let $cp-path := collection("/db/system/repo")//cpcf:config//cpcf:param
let $contentapi-repo := "31533"
let $inject-repo := update value $cp-path[@key="contentapi.repo"] with text {$contentapi-repo}
let $contentapi-branch := "develop"
let $inject-branch := update value $cp-path[@key="contentapi.branch"] with text {$contentapi-branch}
let $contentapi-secret :=
    if (file:exists("/opt/contentapi.env"))
    then file:read("/opt/contentapi.env")
    else "error: could not read contentapi.env - file does not exist"
let $log :=
    if (file:exists("/opt/contentapi.env"))
    then util:log-system-out("Succesfully got gitlab secret for contentapi")
    else util:log-system-out("Error in applying contentapi config: could not read contentapi.env - file does not exist. Please update config manually.")
let $inject-secret := update value $cp-path[@key="contentapi.secret"] with text {$contentapi-secret}
let $contentapi-target := "/db/apps/sade/docs"
let $inject-target := update value $cp-path[@key="contentapi.target"] with text {$contentapi-target}
let $contentapi-multilang-enabled := "true"
let $inject-multilang-enabled := update value $cp-path[@key="contentapi.multilang.enabled"] with text {$contentapi-multilang-enabled}
let $contentapi-multilang-default := "de"
let $inject-multilang-default := update value $cp-path[@key="contentapi.multilang.default"] with text {$contentapi-multilang-default}
let $contentapi-multilang-alt := "en"
let $inject-multilang-alt := update value $cp-path[@key="contentapi.multilang.alt"] with text {$contentapi-multilang-alt}

(: setup zotero api :)
let $ccol := xmldb:create-collection("/db/system", "autostart")
let $chm1 := sm:chmod(xs:anyURI("/db/system/autostart"), "rwxrwx---")
let $copyas := xmldb:copy-resource("/db/apps/sade/modules/system-autostart", "config-zotero.xq", "/db/system/autostart", "config-zotero.xq")
let $chm2 := sm:chmod(xs:anyURI("/db/system/autostart/config-zotero.xq"), "rwxrwx---")

return util:log-system-out("installed " || $project-name)
